--[[ 

	Martin Karer / Sezz, 2008-2010
	A simple minimalistic square minimap

	Changelog:
	2010-11-11:
		[+] Tracking icon tooltip added
		[*] Fixed VehicleSeatIndicator

	2010-10-21:
		[*] Bigger tracking dots fixed (texture updated)

	2010-09-12:
		[:] Cataclysm Update
		[-] Bigger tracking dots disabled (texture propably only needs an update)
		[+] Feedback Button
		
	2010-06-26:
		[*] MinimapCluster was still visible (also fixed WatchFrame position)

	2010-02-11:
		[+] Default Zoom: 0

	2010-02-06:
		[-] Removed BattleField Button

	2009-05-19:
		[*] MinimapZoneTextButton fixed again :D

	2009-04-29:
		[*] Fixed a cosmetic bug (MinimapZoneTextButton tooltip was still there)
		[+] New tracking dots

--]]

-- Martin Karer / Sezz, 2008-2009
-- Minimap: Simple Square Minimap
local dummyFunction = function() return; end;
local sMinimap = CreateFrame("Frame")
local _lstEvents = {
	"PLAYER_LOGIN",
	"PLAYER_ENTERING_WORLD",
	}

local _lstHiddenframes = {
	MinimapZoomIn,
	MinimapZoomOut,
	MinimapBorderTop,
	MinimapToggleButton,
	MiniMapWorldMapButton,
	MiniMapMeetingStoneFrame,
	MiniMapVoiceChatFrame,
	MinimapNorthTag,
	MinimapBorder,
	GameTimeFrame,
	BattlegroundShine,
--	MiniMapBattlefieldFrame,
}

-- Ace Shape
function GetMinimapShape()
	return "SQUARE"
end

-- Event Handler
local Minimap_OnEvent = function(self, event)
	if (event == "PLAYER_ENTERING_WORLD") then
		TimeManagerClockButton:SetParent(UIParent);
		TimeManagerClockButton:Hide();
		TimeManagerClockButton.Show = dummyFunction;
		self:UnregisterEvent(event);
	elseif (event == "PLAYER_LOGIN") then
		-- Activate MouseWheel Zooming
		Minimap:SetZoom(0);
		Minimap:EnableMouseWheel(true)
		Minimap:SetScript("OnMouseWheel", function(self, z)
			local c = Minimap:GetZoom()
			if (z > 0 and c < 5) then
				Minimap:SetZoom(c + 1);
			elseif (z < 0 and c > 0) then
				Minimap:SetZoom(c - 1);
			end
		end);

		self:SetParent(Minimap)
		self:SetAllPoints(Minimap)

		-- Square Style
		Minimap:SetMaskTexture([[Interface\AddOns\sMinimap\SquareMask.blp]])
		sCore:ApplyBackdrop(Minimap);
		
		-- Larger Tracking Dots
		-- Texture stolen from Chinchilla
		Minimap:SetBlipTexture([[Interface\AddOns\sMinimap\TrackingDots.tga]])

		-- Move Minimap
		Minimap:ClearAllPoints()
		Minimap:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", -10, 77);
		Minimap:SetScale(0.8);
		Minimap:SetSize(145, 145);

		-- Move Zone Text
		MinimapZoneTextButton:ClearAllPoints()
		MinimapZoneTextButton:SetPoint("TOP", Minimap, "TOP", 0, sCore:ScaleUp(21));
		MinimapZoneText:SetFontObject(GameFontNormalSmall);
		
		-- Difficulty
		MiniMapInstanceDifficulty:SetParent(Minimap);
		MiniMapInstanceDifficulty:ClearAllPoints();
		MiniMapInstanceDifficulty:SetPoint("TOPRIGHT", Minimap, "TOPRIGHT", 0, sCore:ScaleUp(8));
		MiniMapInstanceDifficultyText:ClearAllPoints();
		MiniMapInstanceDifficultyText:SetPoint("CENTER", MiniMapInstanceDifficulty, "CENTER", 0, 0);
		
		-- Guild Difficulty
		GuildInstanceDifficulty:SetParent(Minimap)
		GuildInstanceDifficulty:ClearAllPoints()
		GuildInstanceDifficulty:SetPoint("TOPRIGHT", Minimap, "TOPRIGHT", 0, 7);
--		GuildInstanceDifficultyText:ClearAllPoints()
--		GuildInstanceDifficultyText:SetPoint("CENTER", MiniMapInstanceDifficulty, "CENTER", 0, 0);

		-- Tracking Frame
		MiniMapTrackingButtonBorder:Hide()
		MiniMapTracking:SetParent(Minimap)
		MiniMapTrackingButton:SetHighlightTexture(nil)
		MiniMapTracking:ClearAllPoints()
		MiniMapTrackingBackground:SetTexture(0, 0, 0, 1)
		MiniMapTrackingIcon:SetAllPoints(MiniMapTrackingBackground)
		MiniMapTrackingIcon:SetTexCoord(.07,.93,.07,.93)
		MiniMapTracking:SetScale(0.7)
		sCore:ApplyBackdropBorder(MiniMapTracking)
		MiniMapTracking:SetPoint("BOTTOMLEFT", 0, -70)
		
		MiniMapTrackingButton:SetScript("OnEnter", function() GameTooltip:SetOwner(self, "ANCHOR_LEFT"); GameTooltip:SetText("Tracking"); end)
		MiniMapTrackingButton:SetScript("OnLeave", function() GameTooltip:Hide(); end)
		
		-- Mail Frame
		MiniMapMailBorder:Hide()
		MiniMapMailFrame:SetParent(Minimap)
		MiniMapMailFrame:ClearAllPoints()
		MiniMapMailFrame:SetScale(0.7)
		MiniMapMailFrame:SetWidth(MiniMapTracking:GetWidth())
		MiniMapMailFrame:SetHeight(MiniMapTracking:GetHeight())
		MiniMapMailFrame:SetPoint("BOTTOMLEFT", 40, -70)
		sCore:ApplyBackdropBorder(MiniMapMailFrame)

		MiniMapMailIcon:SetWidth(MiniMapTrackingIcon:GetWidth())
		MiniMapMailIcon:SetHeight(MiniMapTrackingIcon:GetHeight())
		MiniMapMailIcon:SetTexCoord(.07,.93,.07,.93)
		MiniMapMailIcon:ClearAllPoints()
		MiniMapMailIcon:SetPoint("CENTER", MiniMapMailFrame, "CENTER")

		-- AtlasLoot
		if (AtlasLoot) then
			AtlasLootLoaderDB.MiniMapButton.hide = false;
			AtlasLoot:MiniMapButtonHideShow();

			MiniMapAtlasLootFrame = CreateFrame("Button", "MiniMapAtlasLootFrame")
			MiniMapAtlasLootFrame:SetParent(Minimap)
			MiniMapAtlasLootFrame:ClearAllPoints()
			MiniMapAtlasLootFrame:SetHeight(MiniMapTracking:GetHeight())
			MiniMapAtlasLootFrame:SetWidth(MiniMapTracking:GetWidth())
			MiniMapAtlasLootFrame:SetScale(0.7)
			MiniMapAtlasLootFrame:SetPoint("BOTTOMLEFT", 80, -70)
			sCore:ApplyBackdropBorder(MiniMapAtlasLootFrame)

			MiniMapAtlasLootIcon = MiniMapAtlasLootFrame:CreateTexture()
			MiniMapAtlasLootIcon:ClearAllPoints()
			MiniMapAtlasLootIcon:SetTexCoord(.09,.90,.09,.90)
			MiniMapAtlasLootIcon:SetPoint("CENTER", MiniMapAtlasLootFrame)
			MiniMapAtlasLootIcon:SetHeight(28)
			MiniMapAtlasLootIcon:SetWidth(28)
			MiniMapAtlasLootIcon:SetTexture([[Interface\Icons\INV_Box_01]])

			MiniMapAtlasLootFrame:EnableMouse(true)
			MiniMapAtlasLootFrame:RegisterForClicks("LeftButtonUp")
			MiniMapAtlasLootFrame:SetScript("OnEnter", function(self) GameTooltip:SetOwner(self, "ANCHOR_LEFT"); GameTooltip:SetText("AtlasLoot"); end)
			MiniMapAtlasLootFrame:SetScript("OnLeave", function(self) GameTooltip:Hide(); end)
			MiniMapAtlasLootFrame:SetScript("OnClick", function(self) if (AtlasLootDefaultFrame:IsShown()) then AtlasLootDefaultFrame:Hide(); else AtlasLootDefaultFrame:Show(); end; end)
		end

		-- Battlefield
		MiniMapBattlefieldBorder:Hide()
		MiniMapBattlefieldFrame:SetParent(Minimap)
		MiniMapBattlefieldFrame:ClearAllPoints()
		MiniMapBattlefieldFrame:SetScale(0.7)
		MiniMapBattlefieldFrame:SetWidth(MiniMapTracking:GetWidth())
		MiniMapBattlefieldFrame:SetHeight(MiniMapTracking:GetHeight())
		MiniMapBattlefieldFrame:SetPoint("BOTTOMLEFT", 120, -70)
		sCore:ApplyBackdropBorder(MiniMapBattlefieldFrame)

		MiniMapBattlefieldIcon:SetWidth(MiniMapTrackingIcon:GetWidth())
		MiniMapBattlefieldIcon:SetHeight(MiniMapTrackingIcon:GetHeight())
		MiniMapBattlefieldIcon:SetTexCoord(.07,.93,.07,.93)
		MiniMapBattlefieldIcon:ClearAllPoints()
		MiniMapBattlefieldIcon:SetPoint("CENTER", MiniMapBattlefieldFrame, "CENTER")

		-- Hide default Frames
		for _, sFrame in pairs(_lstHiddenframes) do
			sFrame:SetAlpha(0);
			sFrame:Hide()
			sFrame.Show = dummyFunction;
		end
		
		-- LFG
		MiniMapLFGFrameBorder:Hide()
		MiniMapLFGFrame:SetParent(Minimap)
		MiniMapLFGFrame:ClearAllPoints()
		MiniMapLFGFrame:SetScale(0.7)
		MiniMapLFGFrame:SetWidth(MiniMapTracking:GetWidth())
		MiniMapLFGFrame:SetHeight(MiniMapTracking:GetHeight())
		MiniMapLFGFrame:SetPoint("BOTTOMLEFT", 120, -70)
		MiniMapLFGFrame:SetHighlightTexture(nil)
		sCore:ApplyBackdropBorder(MiniMapLFGFrame)

		MiniMapLFGFrameIcon:SetWidth(MiniMapTrackingIcon:GetWidth())
		MiniMapLFGFrameIcon:SetHeight(MiniMapTrackingIcon:GetHeight())
		MiniMapLFGFrameIcon:SetScale(2)
		MiniMapLFGFrameIcon:ClearAllPoints()
		MiniMapLFGFrameIcon:SetPoint("CENTER", MiniMapLFGFrame, "CENTER")

		LFDSearchStatus:ClearAllPoints();
		LFDSearchStatus:SetPoint("BOTTOMRIGHT", MiniMapLFGFrame, "TOPLEFT");
		LFDSearchStatus:SetClampedToScreen(true);
		
		-- Hide MinimapCluster
		MinimapCluster:SetHeight(1);

		-- Unregister Event
		self:UnregisterEvent(event);
	end
end

-- Register Events
for _, sEvent in pairs(_lstEvents) do
	sMinimap:RegisterEvent(sEvent);
end

-- Setup Minimap
sMinimap:SetScript("OnEvent", Minimap_OnEvent)
